package rip.iwakura.civil;

import java.sql.SQLException;
import java.util.List;
import java.util.UUID;

import org.apache.logging.log4j.LogManager;
import org.bukkit.entity.Player;

import com.j256.ormlite.dao.Dao;
import com.j256.ormlite.dao.DaoManager;
import com.j256.ormlite.jdbc.JdbcConnectionSource;
import com.j256.ormlite.logger.LoggerFactory;
import com.j256.ormlite.support.ConnectionSource;
import com.j256.ormlite.table.TableUtils;

import net.kyori.adventure.text.serializer.plain.PlainTextComponentSerializer;
import rip.iwakura.civil.types.CivilPlayer;
import rip.iwakura.civil.types.CivilTeam;

public class Database {
    private final Dao<CivilPlayer, UUID> playerDao;
    private final Dao<CivilTeam, String> teamDao;
    private ConnectionSource connectionSource;

    public Database(String uri) throws SQLException {
        connectionSource = new JdbcConnectionSource(uri);


        TableUtils.createTableIfNotExists(connectionSource, CivilPlayer.class);
        TableUtils.createTableIfNotExists(connectionSource, CivilTeam.class);

        playerDao = DaoManager.createDao(connectionSource, CivilPlayer.class);
        teamDao = DaoManager.createDao(connectionSource, CivilTeam.class);
    }

    public void createPlayer(Player p) throws SQLException {
        playerDao.create(
                new CivilPlayer(p.getUniqueId(), p.getName())
        );
    }

    public void createTeam(String name, String prefix) throws SQLException {
        teamDao.create(
                new CivilTeam(name, prefix)
        );
    }

    public void joinTeam(Player p, CivilTeam team) throws SQLException {
        CivilPlayer civilPlayer = playerDao.queryForId(p.getUniqueId());
        civilPlayer.setTeam(team);
        playerDao.update(civilPlayer);
    }

    public void joinTeam(CivilPlayer p, CivilTeam team) throws SQLException {
        p.setTeam(team);
        playerDao.update(p);
    }

    public CivilTeam getTeam(String team) throws SQLException {
        return teamDao.queryForId(team);
    }

    public List<CivilTeam> getAllTeams() throws SQLException {
        return teamDao.queryForAll();
    }

    public CivilPlayer getPlayer(String name) throws SQLException {
        return playerDao.queryBuilder().where().eq("name", name).queryForFirst();
    }

    public CivilPlayer getPlayer(UUID uuid) throws SQLException {
        return playerDao.queryForId(uuid);
    }

    public CivilPlayer getPlayer(Player p) throws SQLException {
        return playerDao.queryForId(p.getUniqueId());
    }

    public List<CivilPlayer> getAllPlayers() throws SQLException {
        return playerDao.queryForAll();
    }
}
