package rip.iwakura.civil.commands;

import java.sql.SQLException;

import javax.xml.crypto.Data;

import org.bukkit.entity.Player;

import com.mojang.brigadier.Command;
import com.mojang.brigadier.arguments.StringArgumentType;
import com.mojang.brigadier.builder.LiteralArgumentBuilder;
import com.mojang.brigadier.context.CommandContext;
import com.mojang.brigadier.tree.LiteralCommandNode;

import io.papermc.paper.command.brigadier.CommandSourceStack;
import io.papermc.paper.command.brigadier.Commands;
import net.kyori.adventure.text.Component;
import net.kyori.adventure.text.format.NamedTextColor;
import rip.iwakura.civil.Database;
import rip.iwakura.civil.types.*;

public class Team {
    private Database database;

    public Team(Database database) {
        this.database = database;
    }

    private LiteralArgumentBuilder<CommandSourceStack> createTeam() { 
        return Commands.literal("create")
            .then(
                    Commands.argument("name", StringArgumentType.string())
                    .then(
                        Commands.argument("prefix", StringArgumentType.string())
                        .executes(ctx -> {
                            String name = StringArgumentType.getString(ctx, "name");
                            String prefix = StringArgumentType.getString(ctx, "prefix");

                            try {
                                database.createTeam(name, prefix);
                                return Command.SINGLE_SUCCESS;
                            } catch (SQLException e) {
                                ctx.getSource().getSender().sendMessage(
                                        Component.text(e.getMessage(), NamedTextColor.RED));
                                return 0;
                            }
                        })));
    }

    // Add a player to a team.
    private LiteralArgumentBuilder<CommandSourceStack> joinTeam() {
        return Commands.literal("add")
            .then(
                    Commands.argument("player", new PlayerArgument(database))
                    .then(
                        Commands.argument("team", new TeamArgument(database))
                        .executes(ctx -> {
                            CivilTeam civilTeam = ctx.getArgument("team", CivilTeam.class);
                            CivilPlayer civilPlayer = ctx.getArgument("player",
                                    CivilPlayer.class);

                            try {
                                database.joinTeam(civilPlayer, civilTeam);
                                return Command.SINGLE_SUCCESS;
                            } catch (SQLException e) {
                                ctx.getSource().getSender().sendMessage(
                                        Component.text(e.getMessage(), NamedTextColor.RED));
                                return 0;
                            }
                        })));
    };

    public LiteralCommandNode<CommandSourceStack> getCommand() { 
        return Commands.literal("team")
            .then(createTeam())
            .then(joinTeam()).build();
    }

}
